# Shell script for converting GRASS-output DEM files into files that can be read by az* apps
# (ie squashes header onto one line)
#
# Author: Ben Taylor
# Date: 29/11/2007
#
# 24/June/2008 mggr amended temporary filenames to make the script safe to run multiple instances
# 25/June/2008 benj Added adjustable resolution argument (no checking for wrong arguments though)
#
# Arguments:
# $1: Input file name
# $2: Output file name
# $3: -del to delete GRASS dem when done (default) or -nodel to leave it there
# $4: -res <resolution>, resolution of dem in metres (optional), Nextmap is 5m (default)

RESOLUTION=5 #Res of grid (5 for Nextmap)

if [ ! $2 ] ; then
	echo "Not enough arguments. Usage: demheaderconvert.sh Input_File Output_File [-del|-nodel] [-res <resolution>]"
	exit 1
elif [ $3 ] ; then
	if [ $3 == "-nodel" ] || [ $5 == "-nodel" ]  ; then
		NODELETEFILE=true
    fi
    
    if [ $3 == "-res" ] ; then
        RESOLUTION=$4
    elif [ $4 == "-res" ] ; then
        RESOLUTION=$5
    fi
fi

TEMPDIR=/tmp #Temp directory location - must exist

#Temporary files
HEADERFILE=${TEMPDIR}/tmp_header-$PPID-`date +%s`.txt
LINEHEADER=${TEMPDIR}/tmp_lineheader-$PPID-`date +%s`.txt
TAILFILE=${TEMPDIR}/tmp_tail-$PPID-`date +%s`.txt

FILEORDER=1 #1 for N->S, 0 for S->N


INPUTFILE=$1
OUTPUTFILE=$2

# Split the input file - top six lines are the header info, rest are the DEM data
head -n 6 ${INPUTFILE} > ${HEADERFILE}
tail -n +7 ${INPUTFILE} > ${TAILFILE}

# Run AWK script to extract data from header
awk '{ \
	if ($1 == "north:") NORTH=$2; \
	if ($1 == "south:") SOUTH=$2; \
	if ($1 == "east:") EAST=$2; \
	if ($1 == "west:") WEST=$2; \
	if ($1 == "rows:") ROWS=$2; \
	if ($1 == "cols:") COLS=$2; \
	} \
	END { printf "%s %s %s %s %s %s", COLS, ROWS, WEST, SOUTH, EAST, NORTH }' \
	${HEADERFILE} > ${LINEHEADER}


# Put data together in output
echo ${FILEORDER} `cat ${LINEHEADER}` ${RESOLUTION} > ${OUTPUTFILE}
cat ${TAILFILE} >> ${OUTPUTFILE}

# Delete original DEM file unless user opted not to (don't need it any more)
if [ ! $NODELETEFILE ] ; then
	rm -f ${INPUTFILE}
fi

# Clean up temporary files when done
rm -f ${HEADERFILE}
rm -f ${LINEHEADER}
rm -f ${TAILFILE}
